==> mainshortcuts-1.6.76-py3-none-any.whl: MainShortcuts/dir.py <==
import MainShortcuts.path as m_path
import os as _os
import shutil as _shutil
def create(path,force=False):
  """Создать папку
  Если путь существует, ничего не делает
  force - принудительно создать папку (удалит файл, который находится на её месте)"""
  if m_path.exists(path):
    type=m_path.info(path)["type"]
    if type=="dir":
      return True
    elif force:
      m_path.delete(path)
    else:
      raise Exception("The object exists and is not a folder")
  _os.makedirs(path)
  return True
mk=create
def delete(path):
  """Удалить папку с содержимым
  Если в назначении файл, выдаст ошибку"""
  type=m_path.info(path)["type"]
  if type=="dir":
    _shutil.rmtree(path)
  else:
    raise Exception("Unknown type: "+type)
rm=delete
def copy(fr,to,force=False):
  """Копировать папку с содержимым
  force - принудительно копировать"""
  type=m_path.info(fr)["dir"]
  if type=="dir":
    if m_path.info(to)["type"]!="dir" and force:
      try:
        m_path.delete(to)
      except:
        pass
    _shutil.copytree(fr,to)
  else:
    raise Exception("Unknown type: "+type)
cp=copy
def move(fr,to,force=False):
  """Переместить папку с содержимым
  force - принудительно переместить"""
  type=m_path.info(fr)["dir"]
  if type=="dir":
    if m_path.info(to)["type"]!="dir" and force:
      try:
        m_path.delete(to)
      except:
        pass
    _shutil.move(fr,to)
  else:
    raise Exception("Unknown type: "+type)
def rename(fr,to,force=False):
  """Переименовать папку
  force - принудительно переименовать"""
  t=m_path.info(fr)["dir"]
  if t=="dir":
    if m_path.info(to)["type"]!="dir" and force:
      try:
        m_path.delete(to)
      except:
        pass
    _os.rename(fr,to)
  else:
    raise Exception("Unknown type: "+t)
def list(path,files=True,dirs=True,links=None):
  """Получить список содержимого папки
  files - True: включать файлы в список
          False: не показывать файлы в списке
  dirs  - True: включать папки в список
          False: не показывать папки в списке
  links - None: показывать всё
          True: показывать только ссылки
          False: не показывать ссылки"""
  a=_os.listdir(path)
  b=[]
  for i in a:
    if links==None:
      pass
    elif links==True:
      if not _os.path.islink(i):
        continue
    elif links==False:
      if _os.path.islink(i):
        continue
    else:
      raise Exception('"links" can only be True, False or None')
    if files and os.path.isfile(i):
      b.append(i)
    elif dirs and os.path.isdir(i):
      b.append(i)
  return b

==> mainshortcuts-1.6.82-py3-none-any.whl: MainShortcuts/dir.py <==
import MainShortcuts.path as m_path
import os as _os
import shutil as _shutil
def create(path,force=False):
  """Создать папку
  Если путь существует, ничего не делает
  force - принудительно создать папку (удалит файл, который находится на её месте)"""
  if m_path.exists(path):
    type=m_path.info(path)["type"]
    if type=="dir":
      return True
    elif force:
      m_path.delete(path)
    else:
      raise Exception("The object exists and is not a folder")
  _os.makedirs(path)
  return True
mk=create
def delete(path):
  """Удалить папку с содержимым
  Если в назначении файл, выдаст ошибку"""
  type=m_path.info(path)["type"]
  if type=="dir":
    _shutil.rmtree(path)
  else:
    raise Exception("Unknown type: "+type)
rm=delete
def copy(fr,to,force=False):
  """Копировать папку с содержимым
  force - принудительно копировать"""
  type=m_path.info(fr)["dir"]
  if type=="dir":
    if m_path.info(to)["type"]!="dir" and force:
      try:
        m_path.delete(to)
      except:
        pass
    _shutil.copytree(fr,to)
  else:
    raise Exception("Unknown type: "+type)
cp=copy
def move(fr,to,force=False):
  """Переместить папку с содержимым
  force - принудительно переместить"""
  type=m_path.info(fr)["dir"]
  if type=="dir":
    if m_path.info(to)["type"]!="dir" and force:
      try:
        m_path.delete(to)
      except:
        pass
    _shutil.move(fr,to)
  else:
    raise Exception("Unknown type: "+type)
def rename(fr,to,force=False):
  """Переименовать папку
  force - принудительно переименовать"""
  t=m_path.info(fr)["dir"]
  if t=="dir":
    if m_path.info(to)["type"]!="dir" and force:
      try:
        m_path.delete(to)
      except:
        pass
    _os.rename(fr,to)
  else:
    raise Exception("Unknown type: "+t)
def list(path,files=True,dirs=True,links=None):
  """Получить список содержимого папки
  files - True: включать файлы в список
          False: не показывать файлы в списке
  dirs  - True: включать папки в список
          False: не показывать папки в списке
  links - None: показывать всё
          True: показывать только ссылки
          False: не показывать ссылки"""
  r=[]
  for i in _os.listdir(path):
    i=f"{path}/{i}"
    if links==None:
      pass
    elif links==True:
      if not _os.path.islink(i):
        continue
    elif links==False:
      if _os.path.islink(i):
        continue
    else:
      raise Exception('"links" can only be True, False or None')
    if files and dirs:
      r.append(i)
      continue
    if files:
      if _os.path.isfile(i):
        r.append(i)
        continue
    if dirs:
      if _os.path.isdir(i):
        r.append(i)
        continue
  return r
